@@ -57,10 +57,13 @@ class SRUResponseIterator(BaseSRUIterator):
 
     def __init__(self, srupy, params):
         """Docstring."""
-
         # handle large values for maximumRecords parameter
         self._multipage_threshold = 100
-        self._total_records_wanted = int(params.get("maximumRecords"))
+        if params.get("maximumRecords"):
+            self._total_records_wanted = int(params.get("maximumRecords"))
+        else:
+            self._total_records_wanted = 999999999
+
         if self._total_records_wanted > self._multipage_threshold:
             params.update({
                 'maximumRecords': self._multipage_threshold,
@@ -75,8 +78,11 @@ class SRUResponseIterator(BaseSRUIterator):
         except:
             self.number_of_records = 0
 
-        self.echo = EchoedRequest(self.sru_response.xml.find(
-            './/' + self.srupy.sru_namespace + 'echoedSearchRetrieveRequest'))
+        try:
+            self.echo = EchoedRequest(self.sru_response.xml.find(
+                './/' + self.srupy.sru_namespace + 'echoedSearchRetrieveRequest'))
+        except:
+            self.echo = None
 
         # handle Request parameters
         self._maximum_records = int(params.get('maximumRecords'))
@@ -101,7 +107,8 @@ class SRUResponseIterator(BaseSRUIterator):
 
         (if not all available records were fetched)
         """
-        if self._start_record + self._maximum_records < self._total_records_wanted:
+        if self._start_record + self._maximum_records \
+                < self._total_records_wanted:
             self._start_record += self._maximum_records
             self.params.update({
                 'startRecord': self._start_record,
